@@ -6,5 +6,6 @@
 
 using namespace Eigen;
 VectorXd risk_parity_portfolio_ccd(const MatrixXd&, const VectorXd&, const double, const int);
-double obj_function_roncalli(const MatrixXd&, const VectorXd&, const VectorXd&);
+VectorXd active_risk_parity_portfolio_ccd(const MatrixXd&, const VectorXd&, const VectorXd&,
+                                          const double, const double, const double, const unsigned int);
 #endif
